# Table of Contents

- [fact-sheet-modeling-guidelines](<./fact-sheet-modeling-guidelines.md>)
- [SAP LeanIX](<./SAP-LeanIX.md>)
  - [Table of Contents](<./SAP-LeanIX/Table-of-Contents.md>)
- [Fact Sheet Modeling Guidelines](<./Fact-Sheet-Modeling-Guidelines.md>)
  - [Was this page helpful?](<./Fact-Sheet-Modeling-Guidelines/Was-this-page-helpful.md>)
